abacusai.routing_action — AbacusAI documentation

# abacusai.routing_action

## Classes

`RoutingAction` | Routing action

## Module Contents

class abacusai.routing_action.RoutingAction(client, id=None, title=None, prompt=None, placeholder=None, value=None, displayName=None, isLarge=None, isMedium=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Routing action

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - id (str) – The id of the routing action.

    - title (str) – The title of the routing action.

    - prompt (str) – The prompt of the routing action.

    - placeholder (str) – The placeholder of the routing action.

    - value (str) – The value of the routing action.

    - displayName (str) – The display name of the routing action.

    - isLarge (bool) – UI placement

    - isMedium (bool) – UI placement

  id
  title
  prompt
  placeholder
  value
  display_name
  is_large
  is_medium
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict